//////////////////////////////////////////////////////////////////////////////
//                        I.B.M. CONFIDENTIAL                               //
//      xxxx-yyy (c) COPYRIGHT IBM CORP. 1992   ALL RIGHTS RESERVED.        //
//                                                                          //
//    (I.B.M. CONFIDENTIAL-RESTRICTED when combined with the aggregated     //
//                 OCO source materials for this program.)                  //
//                        OCO SOURCE MATERIAL                               //
//                   LICENSED MATERIALS-PROPERTY OF IBM.                    //
//                                                                          //
//////////////////////////////////////////////////////////////////////////////

/*
 * $Header: /src/master/dx/src/uipp/java/imageWindow.java,v 1.2 2005/10/27 19:43:04 davidt Exp $
 */


import dx.client.*;
import dx.net.*;
import java.applet.*;

public class imageWindow extends ImageWindow {

	public void init() {
		super.init();
	}
    public void start() {
		super.start();
    }
        
} // end imageWindow
